==> hinemos_src-4.0.3.tar.gz: HinemosClient/src_performance/com/clustercontrol/performance/view/action/RefreshPerformanceListAction.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.view.PerformanceListView;

/**
 * 性能[一覧]ビューのリスト表示をリフレッシュするアクションクラス
 * 
 * @version 4.0.0
 * @since 4.0.0
 */
public class RefreshPerformanceListAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.performance.view.action.RefreshPerformanceListAction";

	/**
	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
	 * 
	 * @param view ビューのインスタンス
	 * 
	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
	 */
	@Override
	public void init(IViewPart view) {
	}

	/**
	 * 性能[一覧]ビューを更新します。
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	@Override
	public void run(IAction action) {
		// 収集中リストのビューを取得します。
		IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();

		// 収集中リストのリフレッシュをおこないます。
		PerformanceListView performanceListView = (PerformanceListView) page.findView(PerformanceListView.ID);

		performanceListView.update();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void selectionChanged(IAction action, ISelection selection) {

	}

}

==> hinemos_src-5.0.3.tar.gz: HinemosClient/src_performance/com/clustercontrol/performance/view/action/RefreshPerformanceListAction.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.view.action;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.handlers.HandlerUtil;

import com.clustercontrol.performance.view.PerformanceListView;

/**
 * 性能[一覧]ビューのリスト表示をリフレッシュするアクションクラス
 *
 * @version 5.0.0
 * @since 4.0.0
 */
public class RefreshPerformanceListAction extends AbstractHandler {
	public static final String ID = RefreshPerformanceListAction.class.getName();

	/**
	 * 性能[一覧]ビューを更新します。
	 *
	 * @see org.eclipse.core.commands.IHandler#execute
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		// 収集中リストのビューを取得します。
		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();

		// 収集中リストのリフレッシュをおこないます。
		PerformanceListView performanceListView = (PerformanceListView) page.findView(PerformanceListView.ID);

		performanceListView.update();
		return null;
	}
}
